@@ -4,7 +4,7 @@ __author__ = ["tom van mele"]
 __copyright__ = "Block Research Group - ETH Zurich"
 __license__ = "MIT License"
 __email__ = "van.mele@arch.ethz.ch"
-__version__ = "0.7.0"
+__version__ = "0.9.2"
 
 
 HERE = os.path.dirname(__file__)
@@ -15,21 +15,23 @@ DOCS = os.path.abspath(os.path.join(HOME, "docs"))
 TEMP = os.path.abspath(os.path.join(HOME, "temp"))
 
 
-os.environ['QT_MAC_WANTS_LAYER'] = '1'
-os.environ['QT_API'] = 'pyside2'
+os.environ["QT_MAC_WANTS_LAYER"] = "1"
+os.environ["QT_API"] = "pyside2"
 
 
 try:
     from OpenGL import GL  # noqa: F401
 except Exception:
     from ctypes import util
+
     orig_util_find_library = util.find_library
 
     def new_util_find_library(name):
         res = orig_util_find_library(name)
         if res:
             return res
-        return '/System/Library/Frameworks/' + name + '.framework/' + name
+        return "/System/Library/Frameworks/" + name + ".framework/" + name
+
     util.find_library = new_util_find_library
 
 
