@@ -32,6 +32,7 @@ from compas_view2.forms.dockform import DockForm
 from compas_view2.forms.sceneform import SceneForm
 from compas_view2.forms.propertyform import PropertyForm
 from compas_view2.forms.treeform import TreeForm
+from compas_view2.forms.tabsform import TabsForm
 
 from compas_view2.ui import Button
 from compas_view2.ui import Slider
@@ -51,10 +52,10 @@ from .worker import Worker
 from .plot import MplCanvas
 
 HERE = os.path.dirname(__file__)
-ICONS = os.path.join(HERE, '../icons')
-CONFIG = os.path.join(HERE, 'config.json')
+ICONS = os.path.join(HERE, "../icons")
+CONFIG = os.path.join(HERE, "config.json")
 
-VERSIONS = {'120': (2, 1), '330': (3, 3)}
+VERSIONS = {"120": (2, 1), "330": (3, 3)}
 
 
 class App:
@@ -126,35 +127,35 @@ class App:
 
     """
 
-    def __init__(self,
-                 title: str = 'COMPAS View2',
-                 version: Literal['120', '330'] = '120',
-                 width: int = 800,
-                 height: int = 500,
-                 viewmode: Literal['wireframe', 'shaded', 'ghosted', 'lighted'] = 'shaded',
-                 controller_class: Optional[Controller] = None,
-                 show_grid: bool = True,
-                 config: Optional[dict] = None,
-                 enable_sidebar: bool = False,
-                 enable_sidedock1: bool = False,
-                 enable_sidedock2: bool = False,
-                 enable_sceneform: bool = False,
-                 enable_propertyform: bool = False,
-                 show_flow: bool = False,
-                 flow_view_size: Union[Tuple[int], List[int]] = None,
-                 flow_auto_update: bool = True,
-                 ):
-
+    def __init__(
+        self,
+        title: str = "COMPAS View2",
+        version: Literal["120", "330"] = "120",
+        width: int = 800,
+        height: int = 500,
+        viewmode: Literal["wireframe", "shaded", "ghosted", "lighted"] = "shaded",
+        controller_class: Optional[Controller] = None,
+        show_grid: bool = True,
+        config: Optional[dict] = None,
+        enable_sidebar: bool = False,
+        enable_sidedock1: bool = False,
+        enable_sidedock2: bool = False,
+        enable_sceneform: bool = False,
+        enable_propertyform: bool = False,
+        show_flow: bool = False,
+        flow_view_size: Union[Tuple[int], List[int]] = None,
+        flow_auto_update: bool = True,
+    ):
         if version not in VERSIONS:
-            raise Exception('Only these versions are currently supported: {}'.format(VERSIONS))
+            raise Exception("Only these versions are currently supported: {}".format(VERSIONS))
 
         glFormat = QtGui.QSurfaceFormat()
-        glFormat.setVersion(* VERSIONS[version])
+        glFormat.setVersion(*VERSIONS[version])
 
-        if version == '330':
+        if version == "330":
             View = View330
             glFormat.setProfile(QtGui.QSurfaceFormat.CoreProfile)
-        elif version == '120':
+        elif version == "120":
             View = View120
             glFormat.setProfile(QtGui.QSurfaceFormat.CompatibilityProfile)
         else:
@@ -200,7 +201,11 @@ class App:
 
         self.show_flow = show_flow
         if Flow:
-            self.flow = Flow(self, flow_view_size=flow_view_size or (self.width, self.height), flow_auto_update=flow_auto_update)
+            self.flow = Flow(
+                self,
+                flow_view_size=flow_view_size or (self.width, self.height),
+                flow_auto_update=flow_auto_update,
+            )
 
         self.enable_sidebar = enable_sidebar
         self.enable_sidedock1 = enable_sidedock1
@@ -215,6 +220,7 @@ class App:
         self.init()
         self.resize(width, height)
         self.started = False
+        self.on_object_selected = []
 
     def init(self):
         """Initialize the components of the user interface.
@@ -225,9 +231,9 @@ class App:
 
         """
         self._init_statusbar()
-        self._init_menubar(self.config.get('menubar'))
-        self._init_toolbar(self.config.get('toolbar'))
-        self._init_sidebar(self.config.get('sidebar'))
+        self._init_menubar(self.config.get("menubar"))
+        self._init_toolbar(self.config.get("toolbar"))
+        self._init_sidebar(self.config.get("sidebar"))
         self._init_sidedocks()
 
     def resize(self, width: int, height: int):
@@ -252,29 +258,104 @@ class App:
         y = 0.5 * (rect.height() - height)
         self.window.setGeometry(x, y, width, height)
 
-    def add(self, data: Data, **kwargs) -> Object:
+    def add(
+        self,
+        data: Data,
+        name: str = None,
+        is_selected: bool = None,
+        is_visible: bool = None,
+        show_points: bool = None,
+        show_lines: bool = None,
+        show_faces: bool = None,
+        pointcolor: Union[Color, Dict[Union[str, int], Color]] = None,
+        linecolor: Union[Color, Dict[Union[str, int], Color]] = None,
+        facecolor: Union[Color, Dict[Union[str, int], Color]] = None,
+        linewidth: int = None,
+        pointsize: int = None,
+        opacity: int = None,
+        **kwargs,
+    ) -> Object:
         """Add a COMPAS object.
 
         Parameters
         ----------
-        data: :class:`compas.geometry.Primitive` | :class:`compas.geometry.Shape` | :class:`compas.datastructures.Datastructure`
+        data: :class:`compas.data.Data`
             A COMPAS data object.
+        is_selected : bool, optional
+            Whether the object is selected.
+            Default to False.
+        is_visible : bool, optional
+            Whether to show object.
+            Default to True.
+        show_points : bool, optional
+            Whether to show points/vertices of the object.
+            Default to False.
+        show_lines : bool, optional
+            Whether to show lines/edges of the object.
+            Default to True.
+        show_faces : bool, optional
+            Whether to show faces of the object.
+            Default to True.
+        pointcolor : Union[Color, Dict[Union[str, int], Color]], optional
+            The color or the dict of colors of the points.
+            Default to `compas_view2.objects.Object.default_color_points`.
+        linecolor : Union[Color, Dict[Union[str, int], Color]], optional
+            The color or the dict of colors of the lines.
+            Default to `compas_view2.objects.Object.default_color_lines`.
+        facecolor : Union[Color, Dict[Union[str, int], Color]], optional
+            The color or the dict of colors of the faces.
+            Default to `compas_view2.objects.Object.default_color_faces`.
+        linewidth : int, optional
+            The line width to be drawn on screen
+            Default to 1.
+        pointsize : int, optional
+            The point size to be drawn on screen
+            Default to 10.
+        opacity : float, optional
+            The opacity of the object.
+            Default to 1.0.
         **kwargs : dict, optional
-            Additional visualization options.
+            Additional visualization options for specific objects.
 
         Returns
         -------
         :class:`compas_view2.objects.Object`
+            The added object.
 
         """
-        obj = Object.build(data, **kwargs)
+        if name is not None:
+            kwargs["name"] = name
+        if is_selected is not None:
+            kwargs["is_selected"] = is_selected
+        if is_visible is not None:
+            kwargs["is_visible"] = is_visible
+        if show_points is not None:
+            kwargs["show_points"] = show_points
+        if show_lines is not None:
+            kwargs["show_lines"] = show_lines
+        if show_faces is not None:
+            kwargs["show_faces"] = show_faces
+        if pointcolor is not None:
+            kwargs["pointcolor"] = pointcolor
+        if linecolor is not None:
+            kwargs["linecolor"] = linecolor
+        if facecolor is not None:
+            kwargs["facecolor"] = facecolor
+        if linewidth is not None:
+            kwargs["linewidth"] = linewidth
+        if pointsize is not None:
+            kwargs["pointsize"] = pointsize
+        if opacity is not None:
+            kwargs["opacity"] = opacity
+
+        obj = Object.build(data, app=self, **kwargs)
+
         self.view.objects[obj] = obj
         self.selector.add(obj)
-        obj._app = self
         if self.view.isValid():
             obj.init()
-            if self.dock_slots['sceneform']:
-                self.dock_slots['sceneform'].update()
+            if self.dock_slots["sceneform"]:
+                self.dock_slots["sceneform"].update()
         return obj
 
     def add_reference(self, obj: Object, **kwargs) -> Object:
@@ -331,8 +412,8 @@ class App:
         if Flow and self.show_flow:
             self.flow.show()
 
-        if self.dock_slots['sceneform']:
-            self.dock_slots['sceneform'].update()
+        if self.dock_slots["sceneform"]:
+            self.dock_slots["sceneform"].update()
 
         self._app.exec_()
 
@@ -346,7 +427,7 @@ class App:
         None
 
         """
-        QtWidgets.QMessageBox.about(self.window, 'About', self.config['messages']['about'])
+        QtWidgets.QMessageBox.about(self.window, "About", self.config["messages"]["about"])
 
     def info(self, message: str) -> None:
         """Display info.
@@ -361,7 +442,7 @@ class App:
         None
 
         """
-        result = QtWidgets.QMessageBox.information(self.window, 'Info', message)
+        result = QtWidgets.QMessageBox.information(self.window, "Info", message)
         print(result)
 
     def warning(self, message: str) -> None:
@@ -377,7 +458,7 @@ class App:
         None
 
         """
-        result = QtWidgets.QMessageBox.warning(self.window, 'Warning', message)
+        result = QtWidgets.QMessageBox.warning(self.window, "Warning", message)
         print(result)
 
     def critical(self, message: str) -> None:
@@ -393,7 +474,7 @@ class App:
         None
 
         """
-        result = QtWidgets.QMessageBox.critical(self.window, 'Critical', message)
+        result = QtWidgets.QMessageBox.critical(self.window, "Critical", message)
         print(result)
 
     def question(self, message: str) -> None:
@@ -411,7 +492,7 @@ class App:
         """
         flags = QtWidgets.QMessageBox.StandardButton.Yes
         flags |= QtWidgets.QMessageBox.StandardButton.No
-        response = QtWidgets.QMessageBox.question(self.window, 'Question', message, flags)
+        response = QtWidgets.QMessageBox.question(self.window, "Question", message, flags)
         if response == QtWidgets.QMessageBox.Yes:
             return True
         return False
@@ -440,7 +521,7 @@ class App:
         """
         flags = QtWidgets.QMessageBox.StandardButton.Ok
         flags |= QtWidgets.QMessageBox.StandardButton.Cancel
-        response = QtWidgets.QMessageBox.warning(self.window, 'Confirmation', message, flags)
+        response = QtWidgets.QMessageBox.warning(self.window, "Confirmation", message, flags)
         if response == QtWidgets.QMessageBox.StandardButton.Ok:
             return True
         return False
@@ -473,11 +554,10 @@ class App:
         None
 
         """
-        self.statusFps.setText('fps: {}'.format(fps))
+        self.statusFps.setText("fps: {}".format(fps))
 
     def sidedock(self, title: str = "", slot: str = None, location: str = "right"):
-        """Create a side dock widget.
-        """
+        """Create a side dock widget."""
         if slot and slot in self.dock_slots:
             self.dock_slots[slot].close()
 
@@ -488,7 +568,7 @@ class App:
             "bottom": QtCore.Qt.BottomDockWidgetArea,
         }
 
-        dock = DockForm(title)
+        dock = DockForm(self, title)
         self.window.addDockWidget(locations[location], dock)
 
         if slot:
@@ -497,8 +577,7 @@ class App:
         return dock
 
     def sceneform(self):
-        """Create a side object tree form widget.
-        """
+        """Create a side object tree form widget."""
         if self.dock_slots["sceneform"]:
             self.dock_slots["sceneform"].show()
             return self.dock_slots["sceneform"]
@@ -510,8 +589,7 @@ class App:
         return sceneform
 
     def propertyform(self):
-        """Create a side object tree form widget.
-        """
+        """Create a side object tree form widget."""
         if self.dock_slots["propertyform"]:
             self.dock_slots["propertyform"].show()
             return self.dock_slots["propertyform"]
@@ -522,11 +600,23 @@ class App:
 
         return propertyform
 
-    def treeform(self, title="tree", data=None, slot: str = None, location: str = "left", floating=False, columns=["key", "value"], show_headers=True):
-        """Create a side object tree form widget.
-        """
+    def treeform(
+        self,
+        title="tree",
+        data=None,
+        slot: str = None,
+        location: str = "left",
+        floating=False,
+        columns=["key", "value"],
+        show_headers=True,
+        striped_rows=False,
+    ):
+        """Create a side object tree form widget."""
         if slot and slot in self.dock_slots:
-            self.dock_slots[slot].close()
+            treeform = self.dock_slots[slot]
+            treeform.setWindowTitle(title)
+            treeform.update(data)
+            return treeform
 
         locations = {
             "left": QtCore.Qt.LeftDockWidgetArea,
@@ -535,7 +625,14 @@ class App:
             "bottom": QtCore.Qt.BottomDockWidgetArea,
         }
 
-        treeform = TreeForm(title=title, data=data, columns=columns, show_headers=show_headers)
+        treeform = TreeForm(
+            self,
+            title=title,
+            data=data,
+            columns=columns,
+            show_headers=show_headers,
+            striped_rows=striped_rows,
+        )
         self.window.addDockWidget(locations[location], treeform)
 
         if slot:
@@ -545,16 +642,63 @@ class App:
 
         return treeform
 
+    def tabsform(
+        self,
+        title="tree",
+        tabs=[],
+        slot: str = None,
+        location: str = "left",
+        floating=False,
+        columns=["key", "value"],
+        show_headers=True,
+        striped_rows=False,
+    ):
+        """Create a tabs form widget."""
+        if slot and slot in self.dock_slots:
+            tabsform = self.dock_slots[slot]
+            tabsform.setWindowTitle(title)
+            tabsform.update(tabs)
+            return tabsform
+
+        locations = {
+            "left": QtCore.Qt.LeftDockWidgetArea,
+            "right": QtCore.Qt.RightDockWidgetArea,
+            "top": QtCore.Qt.TopDockWidgetArea,
+            "bottom": QtCore.Qt.BottomDockWidgetArea,
+        }
+
+        tabsform = TabsForm(
+            self,
+            title=title,
+            tabs=tabs,
+            columns=columns,
+            show_headers=show_headers,
+            striped_rows=striped_rows,
+        )
+        self.window.addDockWidget(locations[location], tabsform)
+
+        if slot:
+            self.dock_slots[slot] = tabsform
+        if floating:
+            tabsform.setFloating(True)
+
+        return tabsform
+
     def popup(self, title: str = "", slot: str = None):
-        """Create a side dock widget.
-        """
+        """Create a side dock widget."""
         popup = self.sidedock(title, slot)
         popup.setFloating(True)
         return popup
 
-    def plot(self, title: str = "", location: str = "bottom", floating: bool = False, min_height: int = 200, min_width: int = 200):
-        """Create a matplotlib canvas as dock widget.
-        """
+    def plot(
+        self,
+        title: str = "",
+        location: str = "bottom",
+        floating: bool = False,
+        min_height: int = 200,
+        min_width: int = 200,
+    ):
+        """Create a matplotlib canvas as dock widget."""
         dock = self.sidedock(title, location=location)
         dock.setFloating(floating)
         dock.setMinimumHeight(min_height)
@@ -563,9 +707,15 @@ class App:
         dock.content_layout.addWidget(sc)
         return sc.figure
 
-    def threading(self, func: Callable, args: list = [], kwargs: dict = {},
-                  on_progress: Callable = None, on_result: Callable = None,
-                  include_self: bool = False) -> None:
+    def threading(
+        self,
+        func: Callable,
+        args: list = [],
+        kwargs: dict = {},
+        on_progress: Callable = None,
+        on_result: Callable = None,
+        include_self: bool = False,
+    ) -> None:
         """Execute a multi-threaded function.
 
         Parameters
@@ -605,9 +755,9 @@ class App:
     def _init_statusbar(self):
         self.statusbar = self.window.statusBar()
         self.statusbar.setContentsMargins(0, 0, 0, 0)
-        self.statusText = QtWidgets.QLabel('Ready')
+        self.statusText = QtWidgets.QLabel("Ready")
         self.statusbar.addWidget(self.statusText, 1)
-        self.statusFps = QtWidgets.QLabel('fps: ')
+        self.statusFps = QtWidgets.QLabel("fps: ")
         self.statusbar.addWidget(self.statusFps)
 
     def _init_menubar(self, items: List[Dict]):
@@ -621,9 +771,9 @@ class App:
     def _init_toolbar(self, items: List[Dict]):
         if not items:
             return
-        self.toolbar = self.window.addToolBar('Tools')
+        self.toolbar = self.window.addToolBar("Tools")
         self.toolbar.setMovable(False)
-        self.toolbar.setObjectName('Tools')
+        self.toolbar.setObjectName("Tools")
         self.toolbar.setIconSize(QtCore.QSize(16, 16))
         self._add_toolbar_items(items, self.toolbar)
 
@@ -632,7 +782,7 @@ class App:
             return
         self.sidebar = QtWidgets.QToolBar(self.window)
         self.window.addToolBar(QtCore.Qt.LeftToolBarArea, self.sidebar)
-        self.sidebar.setObjectName('Sidebar')
+        self.sidebar.setObjectName("Sidebar")
         self.sidebar.setMovable(False)
         self.sidebar.setIconSize(QtCore.QSize(16, 16))
         self.sidebar.setMinimumWidth(240)
@@ -654,22 +804,23 @@ class App:
         if not items:
             return
         for item in items:
-            if item['type'] == 'separator':
+            if item["type"] == "separator":
                 parent.addSeparator()
-            elif item['type'] == 'menu':
-                menu = parent.addMenu(item['text'])
-                if 'items' in item:
-                    self._add_menubar_items(item['items'], menu)
-            elif item['type'] == 'radio':
-                radio = QtWidgets.QActionGroup(self.window, exclusive=True)
-                for item in item['items']:
-                    action = self._add_action(parent, text=item['text'], action=item['action'])
+            elif item["type"] == "menu":
+                menu = parent.addMenu(item["text"])
+                if "items" in item:
+                    self._add_menubar_items(item["items"], menu)
+            elif item["type"] == "radio":
+                radio = QtWidgets.QActionGroup(self.window)
+                radio.setExclusive(True)
+                for item in item["items"]:
+                    action = self._add_action(parent, text=item["text"], action=item["action"])
                     action.setCheckable(True)
-                    action.setChecked(item['checked'])
+                    action.setChecked(item["checked"])
                     radio.addAction(action)
-            elif item['type'] == 'action':
-                del item['type']
-                self._add_action(parent, text=item['text'], action=item['action'])
+            elif item["type"] == "action":
+                del item["type"]
+                self._add_action(parent, text=item["text"], action=item["action"])
             else:
                 raise NotImplementedError
 
@@ -677,10 +828,10 @@ class App:
         if not items:
             return
         for item in items:
-            if item['type'] == 'separator':
+            if item["type"] == "separator":
                 parent.addSeparator()
-            elif item['type'] == 'action':
-                del item['type']
+            elif item["type"] == "action":
+                del item["type"]
                 self._add_action(parent, **item)
             else:
                 raise NotImplementedError
@@ -689,31 +840,33 @@ class App:
         if not items:
             return
         for item in items:
-            if item['type'] == 'separator':
+            if item["type"] == "separator":
                 parent.addSeparator()
-            elif item['type'] == 'radio':
-                del item['type']
+            elif item["type"] == "radio":
+                del item["type"]
                 Radio(self, self.sidebar, **item)
-            elif item['type'] == 'checkbox':
-                del item['type']
+            elif item["type"] == "checkbox":
+                del item["type"]
                 Checkbox(self, self.sidebar, **item)
-            elif item['type'] == 'slider':
-                del item['type']
+            elif item["type"] == "slider":
+                del item["type"]
                 Slider(self, self.sidebar, **item)
-            elif item['type'] == 'button':
-                del item['type']
+            elif item["type"] == "button":
+                del item["type"]
                 Button(self, self.sidebar, **item)
             else:
                 raise NotImplementedError
 
-    def _add_action(self,
-                    parent: QtWidgets.QWidget,
-                    *,
-                    text: str,
-                    action: Callable,
-                    args: Optional[List[Any]] = None,
-                    kwargs: Optional[Dict] = None,
-                    icon: Optional[AnyStr] = None):
+    def _add_action(
+        self,
+        parent: QtWidgets.QWidget,
+        *,
+        text: str,
+        action: Callable,
+        args: Optional[List[Any]] = None,
+        kwargs: Optional[Dict] = None,
+        icon: Optional[AnyStr] = None,
+    ):
         action = action if callable(action) else getattr(self.controller, action)
         args = args or []
         kwargs = kwargs or {}
@@ -728,9 +881,7 @@ class App:
     # Decorators
     # ==============================================================================
 
-    def select(self,
-               items: List[Dict[str, Any]],
-               parent=None) -> Callable:
+    def select(self, items: List[Dict[str, Any]], parent=None) -> Callable:
         """Decorator for combo boxes.
 
         Parameters
@@ -742,18 +893,14 @@ class App:
         callable
 
         """
+
         def outer(func: Callable) -> Callable:
-            select = Select(self,
-                            parent or self.sidebar,
-                            items=items,
-                            action=func)
+            select = Select(self, parent or self.sidebar, items=items, action=func)
             return select
+
         return outer
 
-    def radio(self,
-              items: List[Dict[str, Any]],
-              title='',
-              parent=None) -> Callable:
+    def radio(self, items: List[Dict[str, Any]], title="", parent=None) -> Callable:
         """Decorator for radio actions.
 
         Parameters
@@ -765,13 +912,11 @@ class App:
         callable
 
         """
+
         def outer(func: Callable) -> Callable:
-            radio = Radio(self,
-                          parent or self.sidebar,
-                          title=title,
-                          items=items,
-                          action=func)
+            radio = Radio(self, parent or self.sidebar, title=title, items=items, action=func)
             return radio
+
         return outer
 
     def button(self, text: str, parent=None) -> Callable:
@@ -800,12 +945,11 @@ class App:
                 app.info('Thanks for clicking...')
 
         """
+
         def outer(func: Callable) -> Callable:
-            button = Button(self,
-                            parent or self.sidebar,
-                            text=text,
-                            action=func)
+            button = Button(self, parent or self.sidebar, text=text, action=func)
             return button
+
         return outer
 
     def checkbox(self, text: str, checked: bool = True, parent=None) -> Callable:
@@ -836,24 +980,24 @@ class App:
                 app.info('Thanks for checking...')
 
         """
+
         def outer(func: Callable) -> Callable:
-            checkbox = Checkbox(self,
-                                parent or self.sidebar,
-                                text=text,
-                                action=func,
-                                checked=checked)
+            checkbox = Checkbox(self, parent or self.sidebar, text=text, action=func, checked=checked)
             return checkbox
+
         return outer
 
-    def slider(self,
-               title: str,
-               value: int = 0,
-               minval: int = 0,
-               maxval: int = 100,
-               step: int = 1,
-               annotation: str = '',
-               bgcolor: Color = None,
-               parent=None) -> Callable:
+    def slider(
+        self,
+        title: str,
+        value: int = 0,
+        minval: int = 0,
+        maxval: int = 100,
+        step: int = 1,
+        annotation: str = "",
+        bgcolor: Color = None,
+        parent=None,
+    ) -> Callable:
         """Decorator for slider actions.
 
         Parameters
@@ -889,28 +1033,34 @@ class App:
                 app.info('Thanks for sliding...')
 
         """
+
         def outer(func: Callable) -> Callable:
-            slider = Slider(self,
-                            parent or self.sidebar,
-                            func,
-                            value=value,
-                            minval=minval,
-                            maxval=maxval,
-                            step=step,
-                            title=title,
-                            annotation=annotation,
-                            bgcolor=bgcolor)
+            slider = Slider(
+                self,
+                parent or self.sidebar,
+                func,
+                value=value,
+                minval=minval,
+                maxval=maxval,
+                step=step,
+                title=title,
+                annotation=annotation,
+                bgcolor=bgcolor,
+            )
             return slider
+
         return outer
 
-    def on(self,
-           interval: int = None,
-           timeout: int = None,
-           frames: int = None,
-           record: bool = False,
-           record_path: str = 'temp/out.gif',
-           record_fps: int = None,
-           playback_interval: int = None) -> Callable:
+    def on(
+        self,
+        interval: int = None,
+        timeout: int = None,
+        frames: int = None,
+        record: bool = False,
+        record_path: str = "temp/out.gif",
+        record_fps: int = None,
+        playback_interval: int = None,
+    ) -> Callable:
         """Decorator for callbacks of a dynamic drawing process.
 
         Parameters
@@ -952,13 +1102,13 @@ class App:
 
         """
         if (not interval and not timeout) or (interval and timeout):
-            raise ValueError('Must specify either interval or timeout')
+            raise ValueError("Must specify either interval or timeout")
 
         if record:
             # check if record_path is writable
             # create temp dir for frames
             self.tempdir = tempfile.mkdtemp()
-            record_fps = record_fps or 1000/interval
+            record_fps = record_fps or 1000 / interval
 
         def outer(func: Callable):
             def render():
@@ -975,9 +1125,14 @@ class App:
                         #     append_images=self.recorded_frames[1:],
                         #     loop=100)
                         files = [os.path.join(self.tempdir, f"{i}.png") for i in range(frames)]
-                        gif_from_images(files=files, gif_path=record_path, fps=record_fps, delete_files=True)
+                        gif_from_images(
+                            files=files,
+                            gif_path=record_path,
+                            fps=record_fps,
+                            delete_files=True,
+                        )
                         shutil.rmtree(self.tempdir)
-                        print('Recorded to ', record_path)
+                        print("Recorded to ", record_path)
 
             if interval:
                 self.timer = Timer(interval=interval, callback=render)
