@@ -1,11 +1,11 @@
 from matplotlib.figure import Figure
 from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg
 import matplotlib
-matplotlib.use('Qt5Agg')
+
+matplotlib.use("Qt5Agg")
 
 
 class MplCanvas(FigureCanvasQTAgg):
-
     def __init__(self, width=5, height=4, dpi=100):
         self.figure = Figure(figsize=(width, height), dpi=dpi)
         self.figure.update = self.draw
