@@ -5,9 +5,7 @@ from qtpy import QtCore
 
 class SceneForm(DockForm):
     def __init__(self, app, title="Scene"):
-        super().__init__(title)
-
-        self.app = app
+        super().__init__(app, title)
         self.tree = QtWidgets.QTreeWidget()
         self.tree.setColumnCount(1)
         self.tree.setHeaderHidden(True)
@@ -16,7 +14,7 @@ class SceneForm(DockForm):
 
     def update(self):
         self.tree.clear()
-        root_objects = filter(lambda obj: obj.parent is None,  self.app.view.objects.values())
+        root_objects = filter(lambda obj: obj.parent is None, self.app.view.objects.values())
         self.map_objects(root_objects)
 
     def map_objects(self, objects, parent=None):
@@ -32,7 +30,6 @@ class SceneForm(DockForm):
             self.map_objects(obj.children, item)
 
     def show_properties(self, obj):
-
         self.app.selector.select(obj, update=True)
 
         propertyform = self.app.dock_slots.get("propertyform")
